@@ -11,15 +11,17 @@
 #'
 listReferenceSet <- function(organism="hsapiens", hostName="http://www.webgestalt.org/", cache=NULL) {
 	if (startsWith(hostName, "file://")) {
-		jsonData <- fromJSON(file=removeFileProtocol(file.path(hostName, "referencesetsummary.json")))
+		jsonData <- fromJSON(removeFileProtocol(file.path(hostName, "referencesetsummary.json")))
+		idType <- jsonData[[organism]]
+		idType <- idType$name
 	} else {
 		response <- cacheUrl(file.path(hostName, "api", "summary", "referenceset"), cache)
 		if (response$status_code != 200) {
 			return(webRequestError(response))
 		}
 		jsonData <- content(response)
+		idType <- jsonData[[organism]]
+		idType <- sapply(idType,function(e){return(e$name)})
 	}
-	idType <- jsonData[[organism]]
-	idType <- sapply(idType,function(e){return(e$name)})
 	return(idType)
 }
